@@ -40,7 +40,11 @@ class MensajeRespuesta(object):
             '{http://cep.fyg.com/}respuestaCDA',
         )
 
-        return etree.fromstring(respuesta_element.text)  # noqa: S320
+        xml_element = respuesta_element.find('xml')
+
+        return etree.fromstring(  # noqa: S320
+            bytes(xml_element.text, encoding='utf-8'),
+        )
 
 
 class Acuse(BaseModel):
